@@ -493,17 +493,15 @@ class QubesTableModel(QAbstractTableModel):
             return  def_flags | Qt.ItemIsUserCheckable
         return def_flags
 
-vm_shutdown_timeout = 20000  # in msec
 vm_restart_check_timeout = 1000  # in msec
 
 
 class VmShutdownMonitor(QObject):
-    def __init__(self, vm, shutdown_time=vm_shutdown_timeout,
-                 check_time=vm_restart_check_timeout,
+    def __init__(self, vm, check_time=vm_restart_check_timeout,
                  and_restart=False, caller=None):
         QObject.__init__(self)
         self.vm = vm
-        self.shutdown_time = shutdown_time
+        self.shutdown_timeout = vm.shutdown_timeout
         self.check_time = check_time
         self.and_restart = and_restart
         self.shutdown_started = datetime.now()
@@ -519,7 +517,7 @@ class VmShutdownMonitor(QObject):
 
     def timeout_reached(self):
         actual = datetime.now() - self.shutdown_started
-        allowed = timedelta(milliseconds=self.shutdown_time)
+        allowed = timedelta(seconds=self.shutdown_timeout)
 
         return actual > allowed
 
@@ -541,12 +539,12 @@ class VmShutdownMonitor(QObject):
                 msgbox.setText(self.tr(
                         "The Qube <b>'{0}'</b> hasn't shutdown within the last "
                         "{1} seconds, do you want to kill it?<br>").format(
-                            vm.name, self.shutdown_time / 1000))
+                            vm.name, self.shutdown_timeout))
                 kill_button = msgbox.addButton(
                     self.tr("Kill it!"), QMessageBox.YesRole)
                 wait_button = msgbox.addButton(
                     self.tr("Wait another {0} seconds...").format(
-                        self.shutdown_time / 1000),
+                        self.shutdown_timeout),
                     QMessageBox.NoRole)
                 ignore_button = msgbox.addButton(self.tr("Don't ask again"),
                                                  QMessageBox.RejectRole)
@@ -668,7 +666,7 @@ class QubesProxyModel(QSortFilterProxyModel):
         vm = self.sourceModel().data(index, Qt.UserRole)
 
         if self.window.show_running.isChecked() and \
-                vm.state['power'] == 'Running':
+                vm.state['power'] != 'Halted':
             return super().filterAcceptsRow(sourceRow, sourceParent)
         if self.window.show_halted.isChecked() and \
                 vm.state['power'] == 'Halted':
@@ -1061,7 +1059,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
                             update(event="outdated")
             self.proxy.invalidate()
             self.table_selection_changed()
-        except exc.QubesDaemonAccessError:
+        except (exc.QubesDaemonAccessError, exc.QubesVMNotFoundError):
             return  # the VM was deleted before its status could be updated
         except KeyError:  # adding the VM failed for some reason
             self.on_domain_added(None, None, vm)
@@ -1275,7 +1273,8 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     @pyqtSlot(name='on_action_createvm_triggered')
     def action_createvm_triggered(self):
         with common_threads.busy_cursor():
-            create_window = create_new_vm.NewVmDlg(self.qt_app, self.qubes_app)
+            create_window = create_new_vm.NewVmDlg(
+                    self.qt_app, self.qubes_app, self)
         create_window.exec_()
 
     # noinspection PyArgumentList
@@ -1407,24 +1406,52 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
             if reply == QMessageBox.Yes:
                 self.shutdown_vm(vm)
 
-    def shutdown_vm(self, vm, shutdown_time=vm_shutdown_timeout,
-                    check_time=vm_restart_check_timeout, and_restart=False):
+    def get_connected_vms(self, vm, connected_vms):
+        for connected_vm in vm.connected_vms:
+            if connected_vm.is_running():
+                connected_vms.append(connected_vm)
+                self.get_connected_vms(connected_vm, connected_vms)
+
+    def shutdown_vm(self, vm, force=False, check_time=vm_restart_check_timeout,
+                    and_restart=False):
         try:
-            vm.shutdown()
+            connected_vms = []
+
+            if not and_restart:
+                self.get_connected_vms(vm, connected_vms)
+
+            if len(connected_vms) > 0:
+                reply = QMessageBox.question(
+                    self, self.tr("Qube Shutdown Confirmation"),
+                    self.tr("There are some qubes connected to <b>'{0}'</b>!"
+                        "<br><small>Do you want to shutdown: </small>"
+                        "<b>'{1}'</b>?").format(vm.name,
+                            ", ".join([x.name for x in connected_vms])),
+                    QMessageBox.Yes | QMessageBox.Cancel)
+
+                if reply != QMessageBox.Yes:
+                    return False
+
+                force = True
+                for connected_vm in connected_vms:
+                    connected_vm.shutdown(force=force)
+
+            vm.shutdown(force=force)
         except exc.QubesException as ex:
             QMessageBox.warning(
                 self,
                 self.tr("Error shutting down Qube!"),
                 self.tr("ERROR: {0}").format(ex))
-            return
+            return False
 
-        self.shutdown_monitor[vm.qid] = VmShutdownMonitor(vm, shutdown_time,
-                                                          check_time,
+        self.shutdown_monitor[vm.qid] = VmShutdownMonitor(vm, check_time,
                                                           and_restart, self)
         # noinspection PyCallByClass,PyTypeChecker
         QTimer.singleShot(check_time, self.shutdown_monitor[
             vm.qid].check_if_vm_has_shutdown)
 
+        return True
+
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_restartvm_triggered')
     def action_restartvm_triggered(self):
@@ -1441,7 +1468,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
                 # in case the user shut down the VM in the meantime
                 try:
                     if manager_utils.is_running(vm, False):
-                        self.shutdown_vm(vm, and_restart=True)
+                        self.shutdown_vm(vm, force=True, and_restart=True)
                     else:
                         self.start_vm(vm)
                 except exc.QubesException as ex:
@@ -1493,8 +1520,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         try:
             with common_threads.busy_cursor():
                 settings_window = settings.VMSettingsWindow(
-                    vm, init_page=tab, qapp=self.qt_app,
-                    qubesapp=self.qubes_app)
+                    vm, tab, self.qt_app, self.qubes_app, self)
             settings_window.show()
             self.settings_windows[vm.name] = settings_window
         except exc.QubesException as ex:
@@ -1597,7 +1623,8 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         with common_threads.busy_cursor():
             global_settings_window = global_settings.GlobalSettingsWindow(
                 self.qt_app,
-                self.qubes_app)
+                self.qubes_app,
+                self)
         global_settings_window.show()
         self.settings_windows['global_settings_window'] = global_settings_window
 
@@ -1620,7 +1647,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     def action_restore_triggered(self):
         with common_threads.busy_cursor():
             restore_window = restore.RestoreVMsWindow(self.qt_app,
-                                                      self.qubes_app)
+                                                      self.qubes_app, self)
         restore_window.exec_()
 
     # noinspection PyArgumentList
@@ -1670,7 +1697,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_about_qubes_triggered')
     def action_about_qubes_triggered(self):  # pylint: disable=no-self-use
-        about = AboutDialog()
+        about = AboutDialog(self)
         about.exec_()
 
     def createPopupMenu(self):  # pylint: disable=invalid-name
